---
name: g.dirseps
description: Converts any directory separator characters in the input string to or from native host format, and writes the changed path to standard output. Useful in scripts for Windows compatibility.
keywords: [ general, map management, scripts ]
---

# g.dirseps

Internal GRASS utility for converting directory separator characters.

Converts any directory separator characters in the input string to or from native host format, and writes the changed path to standard output. Useful in scripts for Windows compatibility.

=== "Command line"

    **g.dirseps**
    [**-hg**]
    [**path**=*string*]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    g.dirseps
    ```

=== "Python (grass.script)"

    *grass.script.parse_command*("***g.dirseps***",
        **path**=*None*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.parse_command("g.dirseps")
    ```

## Parameters

=== "Command line"

    **path**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;Path to be converted (read from stdin if not specified)  
    **-h**  
    &nbsp;&nbsp;&nbsp;&nbsp;Convert directory separators to native host format  
    **-g**  
    &nbsp;&nbsp;&nbsp;&nbsp;Convert directory separators to GRASS internal format  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **path** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Path to be converted (read from stdin if not specified)  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *h*, *g*  
    &nbsp;&nbsp;&nbsp;&nbsp;**h**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Convert directory separators to native host format  
    &nbsp;&nbsp;&nbsp;&nbsp;**g**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Convert directory separators to GRASS internal format  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*g.dirseps* is an internal tool only. It copies input string to stdout,
changing directory separator characters as specified by flags. It is
used for interoperability between Unix and MS-Windows pathnames.

## AUTHOR

Paul Kelly

## SOURCE CODE

Available at: [g.dirseps source code](https://github.com/OSGeo/grass/tree/main/general/g.dirseps)
([history](https://github.com/OSGeo/grass/commits/main/general/g.dirseps))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
